@@ -32,7 +32,8 @@ mainwindow::mainwindow(QWidget *parent) :
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
     orientationChanged();
     readvalues();
-    abouttext = "CSSU Transitions Tuner ver. 0.0.8<br /><br />Auhtor: d-iivil<br />Licence: GPL";
+    abouttext = "<br />Author: d-iivil<br />Licence: GPL";
+    abouttitle = "CSSU Transitions Tuner ver. 0.0.9";
 }
 
 mainwindow::~mainwindow()
@@ -432,7 +433,7 @@ void mainwindow::on_buttonBox_clicked(QAbstractButton* button)
 	case QDialogButtonBox::HelpRole:
 	{
 	    QMessageBox msgBox;
-	    msgBox.setWindowTitle("CSSU Transitions Tuner");
+	    msgBox.setWindowTitle(abouttitle);
 	    msgBox.setText(abouttext);
 	    msgBox.exec();
 	    break;
